package kr.co.vividnext.sodalive.event

import com.querydsl.jpa.impl.JPAQueryFactory
import kr.co.vividnext.sodalive.event.QEvent.event
import org.springframework.data.jpa.repository.JpaRepository
import org.springframework.stereotype.Repository

@Repository
interface EventRepository : JpaRepository<Event, Long>, EventQueryRepository

interface EventQueryRepository {
    fun getEventList(): List<EventItem>
}

@Repository
class EventQueryRepositoryImpl(private val queryFactory: JPAQueryFactory) : EventQueryRepository {
    override fun getEventList(): List<EventItem> {
        return queryFactory
            .select(
                QEventItem(
                    event.id,
                    event.title,
                    event.thumbnailImage,
                    event.detailImage,
                    event.popupImage,
                    event.link,
                    event.isPopup
                )
            )
            .from(event)
            .where(event.isActive.isTrue)
            .orderBy(event.id.desc())
            .fetch()
    }
}
